@@ -1,14 +1,14 @@
 # $Id: UDP.pm 449 2004-12-27 01:37:33Z sungo $
 package POE::Component::Server::Syslog::UDP;
+$POE::Component::Server::Syslog::UDP::VERSION = '1.22';
+#ABSTRACT: syslog udp server
 
 use warnings;
 use strict;
 
-our $VERSION = '1.20';
-
 sub BINDADDR        () { '0.0.0.0' }
 sub BINDPORT        () { 514 }
-sub DATAGRAM_MAXLEN () { 1024 }  # syslogd defaults to this. as do most 
+sub DATAGRAM_MAXLEN () { 1024 }  # syslogd defaults to this. as do most
                                  # libc implementations of syslog
 
 use Params::Validate qw(validate_with);
@@ -204,13 +204,23 @@ sub unregister {
 }
 
 1;
+
+
+# sungo // vim: ts=4 sw=4 noexpandtab
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-POE::Component::Server::Syslog::UDP
+POE::Component::Server::Syslog::UDP - syslog udp server
+
+=head1 VERSION
+
+version 1.22
 
 =head1 SYNOPSIS
 
@@ -229,6 +239,12 @@ POE::Component::Server::Syslog::UDP
 
 This component provides very simple syslog services for POE.
 
+=for Pod::Coverage        BINDADDR
+       BINDPORT
+       DATAGRAM_MAXLEN
+       select_read
+       socket_start
+
 =head1 CONSTRUCTOR
 
 =head2 spawn()
@@ -349,53 +365,16 @@ This will unregister the sending session from receiving events.
 
 Termintes the component.
 
-=head1 DATE
-
-$Date: 2004-12-26 20:37:33 -0500 (Sun, 26 Dec 2004) $
-
-=head1 REVISION
-
-$Rev: 449 $
-
-Note: This does not necessarily correspond to the distribution version number.
-
 =head1 AUTHOR
 
-Matt Cashner (sungo@cpan.org)
+Matt Cashner (sungo@pobox.com)
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2004, Matt Cashner. All rights reserved.
+This software is Copyright (c) 2017 by Matt Cashner (sungo@pobox.com).
 
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are
-met:
+This is free software, licensed under:
 
-=over 4
-
-=item * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-
-=item * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-=item * Neither the name of the Matt Cashner nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
-
-=back
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+  The (three-clause) BSD License
 
 =cut
-
-1;
-__END__
-
-# sungo // vim: ts=4 sw=4 noexpandtab
