@@ -1,5 +1,7 @@
 # $Id: Syslog.pm 579 2005-11-20 22:52:26Z sungo $
 package POE::Filter::Syslog;
+$POE::Filter::Syslog::VERSION = '1.22';
+#ABSTRACT: syslog parser
 
 use warnings;
 use strict;
@@ -7,8 +9,6 @@ use strict;
 use POE;
 use Time::ParseDate;
 
-our $VERSION = '1.20';
-
 our $SYSLOG_REGEXP = q|
 ^<(\d+)>                       # priority -- 1
 	(?:
@@ -86,17 +86,23 @@ sub get_one {
 sub put {} # XXX
 
 1;
+
+
+# sungo // vim: ts=4 sw=4 noexpandtab
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Filter::Syslog - syslog parser
 
-=head1 AUTHOR
+=head1 VERSION
 
-Matt Cashner (sungo@cpan.org)
+version 1.22
 
 =head1 SYNOPSIS
 
@@ -175,47 +181,16 @@ user name.
 
 =back
 
-=head1 DATE
+=head1 AUTHOR
 
-$Date: 2005-11-20 17:52:26 -0500 (Sun, 20 Nov 2005) $
+Matt Cashner (sungo@pobox.com)
 
-=head1 REVISION
+=head1 COPYRIGHT AND LICENSE
 
-$Rev: 579 $
+This software is Copyright (c) 2017 by Matt Cashner (sungo@pobox.com).
 
-Note: This does not necessarily correspond to the distribution version number.
+This is free software, licensed under:
 
-=head1 LICENSE
-
-Copyright (c) 2003-2005, Matt Cashner. All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are
-met:
-
-=over 4
-
-=item * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-
-=item * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-=item * Neither the name of the Matt Cashner nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
-
-=back
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+  The (three-clause) BSD License
 
 =cut
-
-
-# sungo // vim: ts=4 sw=4 noexpandtab
